# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

import os

from sqlalchemy import *
from elixir import metadata, objectstore, drop_all
from paste.fixture import TestApp
import pkg_resources

from posterity.admin.admin import run_admin
from posterity.app import posterity_app
from posterity.model import Account, UserSession, init_db
from posterity.util import encode_header, local

trans = None

class PosterityTestApp(TestApp):

    def __init__(self):
        app = posterity_app({})
        super(PosterityTestApp, self).__init__(app)
    
    def login(self, username):
        account = Account.get_by(username=username)
        us = UserSession()
        us.account = account
        self.cookies['posterity-session'] = us.cookie
        objectstore.flush()


def setup_empty_db():
    """Test fixture with just one empty account with username=testuser"""
    global trans
    dburi = os.environ.get('POSTERITY_TEST_DBURI', 'sqlite://')
    engine = create_engine(dburi)
    metadata.connect(engine)
    objectstore.clear()
    trans = objectstore.create_transaction()
    init_db()
    a = Account.create('testuser')
    a.set_password('secretpassword')
    objectstore.flush()
    
def setup_simple_db():
    """Test fixture with a database containing some test data"""
    setup_empty_db()
    local.trans = trans # FIXME: this is ugly
    emails = pkg_resources.resource_listdir('posterity.admin', 'tests/data')
    for email in emails:
        if not email.endswith('.eml'):
            continue
        filename = pkg_resources.resource_filename('posterity.admin', 
                                                   'tests/data/' + email)
        run_admin(['posterity-admin', 'inject', '-f', filename, 
                   '-D', 'test:///fixture', 'testuser'])
        
    filename = pkg_resources.resource_filename('posterity.admin', 
                                               'tests/data/test.mbox')
    run_admin(['posterity-admin', 'inject', '--mbox', '-f', filename, 
               '--dburi', 'test:///fixture', 'testuser'])

def teardown_simple_db():
    objectstore.clear()
    trans.rollback()
    drop_all()

